littlemcmc.QuadPotentialDiag
============================

.. currentmodule:: littlemcmc

.. autoclass:: QuadPotentialDiag

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~QuadPotentialDiag.__init__
      ~QuadPotentialDiag.energy
      ~QuadPotentialDiag.raise_ok
      ~QuadPotentialDiag.random
      ~QuadPotentialDiag.reset
      ~QuadPotentialDiag.update
      ~QuadPotentialDiag.velocity
      ~QuadPotentialDiag.velocity_energy
   
   

   
   
   